==> knative-model-5.1.1-sources.jar: annotations/io/fabric8/knative/flows/v1/SequenceSubscriptionStatusFluent.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.knative.internal.pkg.apis.Condition;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface SequenceSubscriptionStatusFluent<A extends SequenceSubscriptionStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildReady instead.
 * @return The buildable object.
 */
@Deprecated public Condition getReady();
    public Condition buildReady();
    public A withReady(Condition ready);
    public Boolean hasReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> withNewReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> withNewReadyLike(Condition item);
    public SequenceSubscriptionStatusFluent.ReadyNested<A> editReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> editOrNewReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> editOrNewReadyLike(Condition item);
    public ObjectReference getSubscription();
    public A withSubscription(ObjectReference subscription);
    public Boolean hasSubscription();
    public interface ReadyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<SequenceSubscriptionStatusFluent.ReadyNested<N>> {

            public N and();
            public N endReady();    }


}

==> knative-model-5.3.0-sources.jar: annotations/io/fabric8/knative/flows/v1/SequenceSubscriptionStatusFluent.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.knative.internal.pkg.apis.Condition;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface SequenceSubscriptionStatusFluent<A extends SequenceSubscriptionStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildReady instead.
 * @return The buildable object.
 */
@Deprecated public Condition getReady();
    public Condition buildReady();
    public A withReady(Condition ready);
    public Boolean hasReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> withNewReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> withNewReadyLike(Condition item);
    public SequenceSubscriptionStatusFluent.ReadyNested<A> editReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> editOrNewReady();
    public SequenceSubscriptionStatusFluent.ReadyNested<A> editOrNewReadyLike(Condition item);
    
/**
 * This method has been deprecated, please use method buildSubscription instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getSubscription();
    public ObjectReference buildSubscription();
    public A withSubscription(ObjectReference subscription);
    public Boolean hasSubscription();
    public SequenceSubscriptionStatusFluent.SubscriptionNested<A> withNewSubscription();
    public SequenceSubscriptionStatusFluent.SubscriptionNested<A> withNewSubscriptionLike(ObjectReference item);
    public SequenceSubscriptionStatusFluent.SubscriptionNested<A> editSubscription();
    public SequenceSubscriptionStatusFluent.SubscriptionNested<A> editOrNewSubscription();
    public SequenceSubscriptionStatusFluent.SubscriptionNested<A> editOrNewSubscriptionLike(ObjectReference item);
    public interface ReadyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<SequenceSubscriptionStatusFluent.ReadyNested<N>> {

            public N and();
            public N endReady();    }


    public interface SubscriptionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<SequenceSubscriptionStatusFluent.SubscriptionNested<N>> {

            public N and();
            public N endSubscription();    }


}
